@@ -20,88 +20,52 @@
  *         Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  */
 
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Geocode = imports.gi.GeocodeGlib;
-const Gio = imports.gi.Gio;
-const Gtk = imports.gi.Gtk;
-const GtkClutter = imports.gi.GtkClutter;
-const Hdy = imports.gi.Handy;
-const WebKit2 = imports.gi.WebKit2;
+import Adw from 'gi://Adw';
+import Gdk from 'gi://Gdk';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Geocode from 'gi://GeocodeGlib';
+import Gio from 'gi://Gio';
+import Gtk from 'gi://Gtk';
+
+import {Geoclue} from './geoclue.js';
+import * as GeocodeFactory from './geocode.js';
+import {MainWindow} from './mainWindow.js';
+import {OSMEdit} from './osmEdit.js';
+import {OSMTypeSearchEntry} from './osmTypeSearchEntry.js';
+import {PlaceStore} from './placeStore.js';
+import {RoutingDelegator} from './routingDelegator.js';
+import {RouteQuery} from './routeQuery.js';
+import {Settings} from './settings.js';
+import * as Utils from './utils.js';
+import * as URIS from './uris.js';
 
-const CheckIn = imports.checkIn;
-const ContactPlace = imports.contactPlace;
 const Format = imports.format;
-const Geoclue = imports.geoclue;
-const GeocodeFactory = imports.geocode;
-const MainWindow = imports.mainWindow;
-const Maps = imports.gi.GnomeMaps;
-const OSMEdit = imports.osmEdit;
-const OSMTypeSearchEntry = imports.osmTypeSearchEntry;
-const PlaceStore = imports.placeStore;
-const RoutingDelegator = imports.routingDelegator;
-const RouteQuery = imports.routeQuery;
-const Settings = imports.settings;
-const Utils = imports.utils;
-const URIS = imports.uris;
 
-// used globally
-var application = null;
-var settings = null;
-var placeStore = null;
-var routingDelegator = null;
-var geoclue = null;
-var networkMonitor = null;
-var checkInManager = null;
-var contactStore = null;
-var osmEdit = null;
-var normalStartup = true;
-var routeQuery = null;
+const _ensuredTypes = [OSMTypeSearchEntry];
 
-const _ensuredTypes = [WebKit2.WebView,
-                       OSMTypeSearchEntry.OSMTypeSearchEntry];
+export class Application extends Adw.Application {
 
-var Application = GObject.registerClass({
-    Properties: {
-        'connected': GObject.ParamSpec.boolean('connected',
-                                               '',
-                                               '',
-                                               GObject.ParamFlags.READABLE |
-                                               GObject.ParamFlags.WRITABLE),
-        'selected-place': GObject.ParamSpec.object('selected-place',
-                                                   'Selected Place',
-                                                   'The selected place',
-                                                   GObject.ParamFlags.READABLE |
-                                                   GObject.ParamFlags.WRITABLE,
-                                                   Geocode.Place),
-        'adaptive-mode': GObject.ParamSpec.boolean('adaptive-mode',
-                                                   'Adaptive Move',
-                                                   'Whether the main window is in adaptive (narrow) mode',
-                                                   GObject.ParamFlags.READABLE |
-                                                   GObject.ParamFlags.WRITABLE),
-    },
-}, class Application extends Gtk.Application {
+    // used globally
+    static application = null;
+    static settings = null;
+    static placeStore = null;
+    static routingDelegator = null;
+    static geoclue = null;
+    static osmEdit = null;
+    static normalStartup = true;
+    static routeQuery = null;
 
-    set connected(p) {
-        this._connected = p;
-        this.notify('connected');
-    }
-
-    get connected() {
-        return this._connected;
-    }
-
-    _init() {
+    constructor() {
         /* Translators: This is the program name. */
         GLib.set_application_name(_("Maps"));
 
         /* Needed to be able to use in UI files */
         _ensuredTypes.forEach((type) => GObject.type_ensure(type));
 
-        super._init({ application_id: pkg.name,
-                      flags: Gio.ApplicationFlags.HANDLES_OPEN |
-                             Gio.ApplicationFlags.HANDLES_COMMAND_LINE });
-        this._connected = false;
+        super({ application_id: pkg.name,
+                flags: Gio.ApplicationFlags.HANDLES_OPEN |
+                       Gio.ApplicationFlags.HANDLES_COMMAND_LINE });
 
         this.add_main_option('local',
                              0,
@@ -119,13 +83,6 @@ var Application = GObject.registerClass({
         this.add_main_option('version', 'v'.charCodeAt(0), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _("Show the version of the program"), null);
 
-        this.add_main_option('force-online',
-                             0,
-                             GLib.OptionFlags.NONE,
-                             GLib.OptionArg.NONE,
-                             _("Ignore network availability"),
-                             null);
-
         this.add_main_option('search',
                              'S'.charCodeAt(0),
                              GLib.OptionFlags.NONE,
@@ -145,47 +102,9 @@ var Application = GObject.registerClass({
                              _("[FILE…|URI]"));
     }
 
-    _checkNetwork() {
-        this.connected =
-            this._forceOnline ||
-            networkMonitor.connectivity === Gio.NetworkConnectivity.FULL;
-    }
-
-    _showContact(id) {
-        contactStore?.lookup(id, (contact) => {
-            this.mark_busy();
-            if (!contact) {
-                this.unmark_busy();
-                return;
-            }
-            contact.geocode(() => {
-                this.unmark_busy();
-                this._mainWindow.mapView.showContact(contact);
-            });
-        });
-    }
-
-    _onShowContactActivate(action, parameter) {
-        this._createWindow();
-        this._checkNetwork();
-        this._mainWindow.present();
-
-        let id = parameter.deep_unpack();
-
-        if (contactStore) {
-            if (contactStore.state === Maps.ContactStoreState.LOADED) {
-                this. _showContact(id);
-            } else {
-                Utils.once(contactStore, 'notify::state', () => {
-                    if (contactStore.state === Maps.ContactStoreState.LOADED)
-                        this._showContact(id);
-                });
-            }
-        }
-    }
-
     _onOsmAccountSetupActivate() {
-        let dialog = osmEdit.createAccountDialog(this._mainWindow, false);
+        let dialog =
+            Application.osmEdit.createAccountDialog(this._mainWindow, false);
 
         dialog.show();
         dialog.connect('response', () => dialog.destroy());
@@ -205,72 +124,28 @@ var Application = GObject.registerClass({
                                  this._openSearchQuery.bind(this, query));
     }
 
-    _addContacts() {
-        if (contactStore) {
-            let contacts = contactStore.get_contacts();
-
-            this._addContactsRecursive(contacts, 0);
-        }
-    }
-
-    _addContactsRecursive(contacts, index) {
-        if (index < contacts.length) {
-            let contact = contacts[index];
-
-            contact.geocode(() => {
-                contact.get_places().forEach((p) => {
-                    if (!p.location)
-                        return
-
-                    Utils.debug('Adding contact address: ' + p.name);
-                    let place = new ContactPlace.ContactPlace({ place: p,
-                                                                contact: contact });
-                    placeStore.addPlace(place, PlaceStore.PlaceType.CONTACT);
-                });
-
-                this._addContactsRecursive(contacts, index + 1);
-            });
-        }
-    }
-
     _initPlaceStore() {
-        placeStore = new PlaceStore.PlaceStore({
-            recentPlacesLimit: settings.get('recent-places-limit'),
-            recentRoutesLimit: settings.get('recent-routes-limit')
+        Application.placeStore = new PlaceStore({
+            recentPlacesLimit: Application.settings.get('recent-places-limit'),
+            recentRoutesLimit: Application.settings.get('recent-routes-limit')
         });
         try {
-            placeStore.load();
+            Application.placeStore.load();
         } catch (e) {
             log('Failed to parse Maps places file, ' +
                 'subsequent writes will overwrite the file!');
         }
-
-        if (contactStore.state === Maps.ContactStoreState.LOADED) {
-            this._addContacts();
-        } else {
-            Utils.once(contactStore, 'notify::state', () => {
-                if (contactStore.state === Maps.ContactStoreState.LOADED)
-                    this._addContacts();
-            });
-        }
     }
 
     vfunc_startup() {
         super.vfunc_startup();
 
-        GtkClutter.init(null);
-        Hdy.init();
-
         Utils.loadStyleSheet(Gio.file_new_for_uri('resource:///org/gnome/Maps/application.css'));
 
-        application = this;
+        Application.application = this;
         this._initServices();
 
         Utils.addActions(this, {
-            'show-contact': {
-                paramType: 's',
-                onActivate: this._onShowContactActivate.bind(this)
-            },
             'osm-account-setup': {
                 onActivate: this._onOsmAccountSetupActivate.bind(this)
             },
@@ -282,40 +157,32 @@ var Application = GObject.registerClass({
                 onActivate: () => this.quit(),
                 accels: ['<Primary>Q']
             }
-        }, settings);
+        }, Application.settings);
 
+        let display = Gdk.Display.get_default();
 
-        this._styleManager = Hdy.StyleManager.get_default();
-        this._styleManager.set_color_scheme(Hdy.ColorScheme.PREFER_LIGHT);
-
-        Gtk.IconTheme.get_default().append_search_path(GLib.build_filenamev([pkg.pkgdatadir,
-                                                                             'icons']));
+        Gtk.IconTheme.get_for_display(display).add_search_path(
+            GLib.build_filenamev([pkg.pkgdatadir, 'icons']));
         this._initPlaceStore();
     }
 
     _initServices() {
-        settings         = Settings.getSettings('org.gnome.Maps');
-        routeQuery       = new RouteQuery.RouteQuery();
-        routingDelegator = new RoutingDelegator.RoutingDelegator({ query: routeQuery });
-        geoclue          = new Geoclue.Geoclue();
-        networkMonitor   = Gio.NetworkMonitor.get_default();
-        networkMonitor.connect('network-changed',
-                               this._checkNetwork.bind(this));
-        checkInManager = new CheckIn.CheckInManager();
-        contactStore = new Maps.ContactStore();
-        contactStore.load();
-        osmEdit = new OSMEdit.OSMEdit();
+        Application.settings = Settings.getSettings('org.gnome.Maps');
+        Application.routeQuery = new RouteQuery();
+        Application.routingDelegator = new RoutingDelegator({ query: Application.routeQuery });
+        Application.geoclue = new Geoclue();
+        Application.osmEdit = new OSMEdit();
     }
 
     _createWindow() {
         if (this._mainWindow)
             return;
 
-        this._mainWindow = new MainWindow.MainWindow({ application: this });
+        this._mainWindow = new MainWindow({ application: this });
         this._mainWindow.connect('destroy', () => this._onWindowDestroy());
         if (GLib.getenv('MAPS_DEBUG') === 'focus') {
             this._mainWindow.connect('set-focus', (window, widget) => {
-                log('* focus widget: %s'.format(widget));
+                log(`* focus widget: ${widget}`);
             });
         }
     }
@@ -331,12 +198,11 @@ var Application = GObject.registerClass({
 
     vfunc_activate() {
         this._createWindow();
-        this._checkNetwork();
         this._mainWindow.present();
     }
 
     _openInternal(files) {
-        if (!this._mainWindow || !this._mainWindow.mapView.view.realized)
+        if (!this._mainWindow || !this._mainWindow.mapView.map.get_realized())
             return;
 
         let uri = files[0].get_uri();
@@ -372,7 +238,7 @@ var Application = GObject.registerClass({
         /* unless there's exactly one place (which should be focused) in
          * the results, let the stored location be used on startup
          */
-        normalStartup = true;
+        Application.normalStartup = true;
         this.connect('shutdown', () => cancellable.cancel());
         GeocodeFactory.getGeocoder().search(query, null, null, cancellable,
                                             (places, error) => {
@@ -392,7 +258,7 @@ var Application = GObject.registerClass({
                         /* don't use the stored location on startup, as we're
                          * zooming in directly on the place
                          */
-                        normalStartup = false;
+                        Application.normalStartup = false;
                         this._mainWindow.mapView.showPlace(places[0], true);
                     } else {
                         this._mainWindow.placeEntry.grab_focus();
@@ -421,15 +287,15 @@ var Application = GObject.registerClass({
         let uri = files[0].get_uri();
 
         if (GLib.uri_parse_scheme(uri) !== 'maps')
-            normalStartup = false;
+            Application.normalStartup = false;
 
         this.activate();
 
         let mapView = this._mainWindow.mapView;
-        if (mapView.view.realized)
+        if (mapView.map.get_realized())
             this._openInternal(files);
         else
-            mapView.view.connect('notify::realized',
+            mapView.map.connect('realize',
                                  this._openInternal.bind(this, files));
     }
 
@@ -439,7 +305,7 @@ var Application = GObject.registerClass({
         if (options.contains('local')) {
             let variant = options.lookup_value('local', null);
             this.local_tile_path = variant.deep_unpack();
-            normalStartup = false;
+            Application.normalStartup = false;
             if (options.contains('local-tile-size')) {
                 variant = options.lookup_value('local-tile-size', null);
                 this.local_tile_size = variant.deep_unpack();
@@ -450,8 +316,6 @@ var Application = GObject.registerClass({
              * leaving the running instance unaffected
              */
             return 0;
-        } else if (options.contains('force-online')) {
-            this._forceOnline = true;
         }
 
         let remaining = options.lookup(GLib.OPTION_REMAINING, null);
@@ -486,12 +350,31 @@ var Application = GObject.registerClass({
     }
 
     _onWindowDestroy(window) {
-        /* as a workaround, manually dispose the contact store here
-         * to avoid a crash when it's being disposed as a result of the
-         * GC sweep at exit, probably due to some event loop race condition
-         */
-        contactStore.run_dispose();
-        contactStore = null;
         this._mainWindow = null;
     }
-});
+
+    vfunc_shutdown() {
+        // need to unparent popover children to avoid GTK warnings on exit
+        if (this._mainWindow) {
+            this._mainWindow.placeEntry.popover.unparent();
+        }
+        this._mainWindow.sidebar.unparentSearchPopovers();
+        super.vfunc_shutdown();
+    }
+}
+
+GObject.registerClass({
+    Properties: {
+        'selected-place': GObject.ParamSpec.object('selected-place',
+                                                   'Selected Place',
+                                                   'The selected place',
+                                                   GObject.ParamFlags.READABLE |
+                                                   GObject.ParamFlags.WRITABLE,
+                                                   Geocode.Place),
+        'adaptive-mode': GObject.ParamSpec.boolean('adaptive-mode',
+                                                   'Adaptive Move',
+                                                   'Whether the main window is in adaptive (narrow) mode',
+                                                   GObject.ParamFlags.READABLE |
+                                                   GObject.ParamFlags.WRITABLE),
+    }
+}, Application);
