@@ -19,21 +19,20 @@
  * Author: Damián Nohales <damiannohales@gmail.com>
  */
 
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Mainloop = imports.mainloop;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Graphene from 'gi://Graphene';
+import Gtk from 'gi://Gtk';
 
-const Application = imports.application;
-const ContactPlace = imports.contactPlace;
-const GeocodeFactory = imports.geocode;
-const Place = imports.place;
-const PlaceView = imports.placeView;
-const PlaceButtons = imports.placeButtons;
-const PlaceFormatter = imports.placeFormatter;
-const PlaceStore = imports.placeStore;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import * as GeocodeFactory from './geocode.js';
+import {Place} from './place.js';
+import {PlaceView} from './placeView.js';
+import {PlaceButtons} from './placeButtons.js';
+import {PlaceFormatter} from './placeFormatter.js';
+import {PlaceStore} from './placeStore.js';
+import * as Utils from './utils.js';
 
 /* Maximum width of the popover content before it's forced to wrap */
 const MAX_CONTENT_WIDTH = 350;
@@ -41,37 +40,66 @@ const MAX_CONTENT_WIDTH = 350;
    contents */
 const HEIGHT_MARGIN = 100;
 
-var MapBubble = GObject.registerClass(
-class MapBubble extends Gtk.Popover {
+export class MapBubble extends Gtk.Popover {
 
-    _init(params) {
+    constructor(params) {
         let place = params.place;
         delete params.place;
 
         let mapView = params.mapView;
         delete params.mapView;
 
-        params.relative_to = mapView;
-        params.transitions_enabled = false;
-        params.modal = false;
+        super(params);
 
-        super._init(params);
-
-        let content = new PlaceView.PlaceView({ place, mapView, visible: true });
+        let content = new PlaceView({ place, mapView, visible: true });
 
         let scrolledWindow = new MapBubbleScrolledWindow({ visible: true,
                                                            propagateNaturalWidth: true,
                                                            propagateNaturalHeight: true,
-                                                           hscrollbarPolicy: Gtk.PolicyType.NEVER });
-        scrolledWindow.add(content);
-        this.add(scrolledWindow);
+                                                           hscrollbarPolicy: Gtk.PolicyType.NEVER,
+                                                           child: content });
+        this.child = scrolledWindow;
 
         this.get_style_context().add_class("map-bubble");
     }
-});
+}
 
-var MapBubbleScrolledWindow = GObject.registerClass(
-class MapBubbleScrolledWindow extends Gtk.ScrolledWindow {
+GObject.registerClass(MapBubble);
+
+export class MapBubbleScrolledWindow extends Gtk.ScrolledWindow {
+    /*
+    vfunc_get_request_mode() {
+        return Gtk.SizeRequestMode.HEIGHT_FOR_WIDTH;
+    }
+    */
+
+    /*
+    vfunc_measure(orientation, forSize) {
+        log('measure: ' + orientation + ', ' + forSize);
+
+        let [cm, cn, cbx, cby] = this.child.measure(orientation, forSize);
+
+        log('child measure: ' + cm + ', ' + cn);
+
+        // TODO: fix
+        return [500, 500, null, null];
+
+        if (orientation === Gtk.Orientation.HORIZONTAL) {
+            let windowHeight = this.get_toplevel().get_allocated_height() - HEIGHT_MARGIN;
+            let [min, nat] = this.get_child().get_preferred_height_for_width(width);
+            min = Math.min(min, windowHeight);
+            nat = Math.min(nat, windowHeight);
+            return [min, nat, 0, 0];
+        } else {
+            let [min, nat] = this.get_child().get_preferred_width();
+            min = Math.min(min, MAX_CONTENT_WIDTH);
+            nat = Math.min(nat, MAX_CONTENT_WIDTH);
+            return [min, nat, 0, 0];
+        }
+    }
+    */
+
+    /*
     vfunc_get_preferred_width() {
         let [min, nat] = this.get_child().get_preferred_width();
         min = Math.min(min, MAX_CONTENT_WIDTH);
@@ -86,17 +114,29 @@ class MapBubbleScrolledWindow extends Gtk.ScrolledWindow {
         nat = Math.min(nat, windowHeight);
         return [min, nat];
     }
+    */
 
-    vfunc_draw(cr) {
+    /*
+    vfunc_snapshot(snapshot) {
         let popover = this.get_ancestor(Gtk.Popover);
         if (popover) {
-            let [{x, y, width, height}, baseline] = this.get_allocated_size();
+            let {x, y, width, height} = this.get_allocation();
+            let rect = new Graphene.Rect();
 
+            log('allocation: ' + [x, y]);
+
+            rect.init(x, y, width, height);
+
+            let cr = snapshot.append_cairo(rect);
             // clip the top corners to the rounded corner
+
             let radius = popover.get_style_context()
                                 .get_property(Gtk.STYLE_PROPERTY_BORDER_RADIUS, popover.get_state_flags())
                                 * this.scale_factor;
 
+            // TODO: how to do this?
+            let radius = 0;
+
             // bottom left
             cr.moveTo(0, height);
             cr.lineTo(0, radius);
@@ -105,9 +145,13 @@ class MapBubbleScrolledWindow extends Gtk.ScrolledWindow {
             cr.lineTo(width, height);
 
             cr.clip();
+            cr.$dispose();
         }
 
-        return super.vfunc_draw(cr);
+        super.vfunc_snapshot(snapshot);
     }
-});
+    */
+}
+
+GObject.registerClass(MapBubbleScrolledWindow);
 
