@@ -107,9 +107,8 @@ export class MapView extends Gtk.Overlay {
         let isValid = Application.routeQuery.isValid();
 
         this._routingOpen = value && isValid;
-        // TODO: bring it back when the layers are working
-        //this._routeLayers.forEach((routeLayer) => routeLayer.visible = value && isValid);
-        //this._instructionMarkerLayer.visible = value && isValid;
+        this._routeLayers.forEach((routeLayer) => routeLayer.visible = value && isValid);
+        this._instructionMarkerLayer.visible = value && isValid;
         if (!value)
             this.routeShowing = false;
         this.notify('routingOpen');
@@ -446,9 +445,7 @@ export class MapView extends Gtk.Overlay {
             Application.settings.set('map-type', mapType);
         } else {
             let source = new GnomeMaps.FileDataSource({
-                path: Utils.getBufferText(Application.application.local_tile_path),
-                renderer: renderer,
-                tile_size: Application.application.local_tile_size || 512
+                path: Utils.getBufferText(Application.application.local_tile_path)
             });
             try {
                 source.prepare();
@@ -456,8 +453,8 @@ export class MapView extends Gtk.Overlay {
                 mapSource =
                     new Shumate.RasterRenderer({ id: 'local',
                                                  name: 'local',
-                                                 min_zoom_level: source.min_zoom_level,
-                                                 max_zoom_level: source.max_zoom_level,
+                                                 min_zoom_level: source.min_zoom,
+                                                 max_zoom_level: source.max_zoom,
                                                  tile_size:      Application.application.local_tile_size ?? 512,
                                                  projection:     Shumate.MapProjection.MERCATOR,
                                                  data_source:    source });
@@ -465,6 +462,7 @@ export class MapView extends Gtk.Overlay {
                 this.setMapType(MapView.MapType.STREET);
                 Application.application.local_tile_path = false;
                 Utils.showDialog(e.message, Gtk.MessageType.ERROR, this._mainWindow);
+                return;
             }
         }
 
@@ -776,7 +774,7 @@ export class MapView extends Gtk.Overlay {
 
     showTurnPoint(turnPoint) {
         if (this._turnPointMarker)
-            this._turnPointMarker.destroy();
+            this._instructionMarkerLayer.remove_marker(this._turnPointMarker);
 
         this._turnPointMarker = null;
         if (turnPoint.isStop())
@@ -790,7 +788,7 @@ export class MapView extends Gtk.Overlay {
 
     showTransitStop(transitStop, transitLeg) {
         if (this._turnPointMarker)
-            this._turnPointMarker.destroy();
+            this._instructionMarkerLayer.remove_marker(this._turnPointMarker);
 
         this._turnPointMarker = new TurnPointMarker({ transitStop: transitStop,
                                                       transitLeg: transitLeg,
