@@ -19,25 +19,23 @@
  * Author: Damián Nohales <damiannohales@gmail.com>
  */
 
-const GObject = imports.gi.GObject;
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const MapMarker = imports.mapMarker;
+import {MapMarker} from './mapMarker.js';
 
-var PlaceMarker = GObject.registerClass(
-class PlaceMarker extends MapMarker.MapMarker {
+export class PlaceMarker extends MapMarker {
 
-    _init(params) {
-        super._init(params);
+    constructor(params) {
+        super(params);
 
-        this.add_actor(this._actorFromIconName('mark-location', 32));
-    }
-
-    get anchor() {
-        return { x: Math.floor(this.width / 2),
-                 y: this.height - 3 };
+        this._image.icon_name = 'mark-location';
+        this._image.icon_size = Gtk.IconSize.LARGE;
     }
 
     _hasBubble() {
         return true;
     }
-});
+}
+
+GObject.registerClass(PlaceMarker);
